SW update - BeagleBone Black
================
Get meta-ti at <https://git.yoctoproject.org/cgit/cgit.cgi/meta-ti/>.
Get meta-swupdate at <https://github.com/sbabic/meta-swupdate/>.
Get meta-openembedded <https://github.com/openembedded/meta-openembedded.git>.
Tested with:
```
poky             : warrior:2ce6c7b190fc418a5653085f83016b29d52a2ae5
meta-ti          : master:0fe9243e8047c13edd860f73ca1d781c0f2a1a1b
meta-swupdate    : warrior: 7ebe40f1a9b312476580fc74541231ac202feaa4
meta-openembedded: warrior: a24acf94d48d635eca668ea34598c6e5c857e3f8
meta-debian      : warrior: c747772def6844f4c9c8810d1e7ad556ce91e12a
```

Build
-----
1. Setup build directory.
   ```sh
   $ export TEMPLATECONF=meta-debian/conf
   $ source ./poky/oe-init-build-env build-bbb
   ```

2. Add `meta-ti`, `meta-swupdate`, `meta-openembedded/meta-oe`, `meta-debian/bsp/meta-swupdate` and `meta-debian/bsp/meta-ti` to `conf/bblayers.conf`.
   ```sh
   $ vi conf/bblayers.conf
   ...
   BBLAYERS ?= " \
     /path/to/poky/meta \
     /path/to/poky/meta-poky \
     /path/to/poky/meta-debian \
     /path/to/poky/meta-debian/bsp/meta-ti \
     /path/to/poky/meta-debian/bsp/meta-swupdate \
     /path/to/poky/meta-ti \
     /path/to/poky/meta-swupdate \
     /path/to/poky/meta-openembedded/meta-oe \
     "
   ```

3. Set `MACHINE` to `beaglebone`.
   ```sh
   $ vi conf/local.conf
   ...
   MACHINE ??= "beaglebone"
   ...
   ```
4. Build.
   ```sh
   $ bitbake core-image-minimal
   ```

After finish building, in `tmp/deploy/images/beaglebone/`, these files should be available:

* `MLO`
* `u-boot.img` (U-Boot)
* `zImage` (Kernel)
* `am335x-boneblack.dtb` (Kernel device tree)
* `core-image-minimal-beaglebone-<date>.rootfs.ext4` (rootfs)

Install root file system, kernel and bootloader
----
1. Create three partitions on the SD card: BOOT (FAT32), ROOTFS1 (ext4) and ROOTFS2 (ext4).
If there is enough space on the storage to save two copies of the whole software, it is possible to guarantee that there is always a working copy even if the software update is interrupted or a power off occurs.
2. Install the root file system into `ROOTFS1` and `ROOTFS2`.
   ```sh
   $ sudo cp -rf /mount/dir/of/core-image-minimal-beaglebone-<date>.rootfs.ext4/* /mount/dir/of/ROOTFS1
   $ sudo cp -rf /mount/dir/of/core-image-minimal-beaglebone-<date>.rootfs.ext4/* /mount/dir/of/ROOTFS2
   ```
3. Install kernel
   ```sh
   $ sudo cp zImage am335x-boneblack.dtb /mount/dir/of/BOOT
   ```
4. Install the bootloader. Set `mmcroot` is `/dev/mmcblk0p3` (ROOTFS2).
   ```sh
   $ sudo cp MLO u-boot.img /mount/dir/of/BOOT
   $ sudo cat <<\EOF > /mount/dir/of/BOOT/uEnv.txt
   bootpart=0:3
   bootdir=/boot
   bootfile=zImage
   console=ttyO0,115200n8
   fdtaddr=0x81000000
   fdtfile=am335x-boneblack.dtb
   loadaddr=0x80008000
   mmcroot=/dev/mmcblk0p3 rw
   mmcrootfstype=ext4 rootwait
   mmcargs=setenv bootargs console=${console} root=${mmcroot} rootfstype=${mmcrootfstype}
   loadfdt=load mmc ${bootpart} ${fdtaddr} ${bootdir}/${fdtfile}
   loadimage=load mmc ${bootpart} ${loadaddr} ${bootdir}/${bootfile}
   uenvcmd=if run loadfdt; then echo Loaded ${fdtfile}; if run loadimage; then run mmcargs; bootz ${loadaddr} - ${fdtaddr}; fi; fi;
   EOF
   ```
Testing SW update
----
1. Create a simple `sw-description`
   ```sh
   $ cd /path/to/build-bbb/tmp/deploy/images/beaglebone
   $ vi sw-description
   software =
    {
            version = "1.0";
            bootloader_transaction_marker = false;
            hardware-compatibility: [ "RevC" ];
            images: (
                    {
                            filename = "core-image-minimal-beaglebone-<date>.rootfs.ext4";
                            device = "/dev/mmcblk0p2";
                            type = "raw";
                    }
            );
            files: (
                    {
                            filename = "uEnv.txt";
                            path = "/uEnv.txt";
                            device = "/dev/mmcblk0p1";
                            filesystem = "vfat"
                    }
            );
    }
   ```
2. Create new uEnv.txt file to update the "bootpart" and "mmcroot"
   ```sh
   $ cd /path/to/build-bbb/tmp/deploy/images/beaglebone
   $ vi uEnv.txt
   bootpart=0:2
   bootdir=/boot
   bootfile=zImage
   console=ttyO0,115200n8
   fdtaddr=0x81000000
   fdtfile=am335x-boneblack.dtb
   loadaddr=0x80008000
   mmcroot=/dev/mmcblk0p2 rw
   mmcrootfstype=ext4 rootwait
   mmcargs=setenv bootargs console=${console} root=${mmcroot} rootfstype=${mmcrootfstype}
   loadfdt=load mmc ${bootpart} ${fdtaddr} ${bootdir}/${fdtfile}
   loadimage=load mmc ${bootpart} ${loadaddr} ${bootdir}/${bootfile}
   uenvcmd=if run loadfdt; then echo Loaded ${fdtfile}; if run loadimage; then run mmcargs; bootz ${loadaddr} - ${fdtaddr}; fi; fi;
   EOF
   ```
3. Create an update image (`test-swupdate.swu`) and `hwrevision` files, then install them to `ROOTFS2`
   ```sh
   $ cd /path/to/build-bbb/tmp/deploy/images/beaglebone
   $ for i in sw-description uEnv.txt core-image-minimal-beaglebone-<date>.rootfs.ext4; do echo $i;done | cpio -ov -H crc > test-swupdate.swu
   $ sudo cp test-swupdate.swu /mount/dir/of/ROOTFS2/root/
   $ sudo sh -c 'echo "beaglebone RevC" > /mount/dir/of/ROOTFS2/etc/hwrevision'
   ```
4. Run `swupdate` to update the `ROOTFS1`
   Boot the board and login with `root` (no password), then run `swupdate` command:
   ```sh
   # swupdate -i /root/test-swupdate.swu -v
   ```
5. Check status and the version of rootfs after updated.
   Output logs like:
   ```
    [TRACE] : SWUPDATE running :  [extract_sw_description] : Found file:
            filename sw-description
            size 379
            checksum 0x6e6e VERIFIED
    [TRACE] : SWUPDATE running :  [get_common_fields] : Version 1.0
    [TRACE] : SWUPDATE running :  [get_common_fields] : Setting bootloader transaction marker: false
    [TRACE] : SWUPDATE running :  [parse_hw_compatibility] : Accepted Hw Revision : RevC
    [TRACE] : SWUPDATE running :  [parse_files] : Found File: uEnv.txt --> /uEnv.txt (/dev/mmcblk0p1)
    [TRACE] : SWUPDATE running :  [parse_images] : Found Image: core-image-minimal-beaglebone-20200302070450                                                     .rootfs.ext4 in device : /dev/mmcblk0p2 for handler raw
    [TRACE] : SWUPDATE running :  [check_hw_compatibility] : Hardware beaglebone Revision: RevC
    [TRACE] : SWUPDATE running :  [check_hw_compatibility] : Hardware compatibility verified
    [TRACE] : SWUPDATE running :  [cpio_scan] : Found file:
            filename uEnv.txt
            size 532
            REQUIRED
    [TRACE] : SWUPDATE running :  [cpio_scan] : Found file:
            filename core-image-minimal-beaglebone-20200302070450.rootfs.ext4
            size 20618240
            REQUIRED
    [TRACE] : SWUPDATE running :  [listener_create] : creating socket at /tmp/swupdateprog
    [TRACE] : SWUPDATE running :  [network_initializer] : Main loop Daemon
    [TRACE] : SWUPDATE running :  [listener_create] : creating socket at /tmp/sockinstctrl
    [TRACE] : SWUPDATE running :  [install_single_image] : Found installer for stream core-image-minimal-bea                                                     glebone-20200302070450.rootfs.ext4 raw
    [TRACE] : SWUPDATE running :  [install_single_image] : Found installer for stream uEnv.txt rawfile
    [  128.881091] FAT-fs (mmcblk0p1): Volume was not properly unmounted. Some data may be corrupt. Please r                                                     un fsck.
    [TRACE] : SWUPDATE running :  [install_raw_file] : Installing file uEnv.txt on /tmp/datadst//uEnv.txt
    Software updated successfully
    Please reboot the device to start the new software
    [INFO ] : SWUPDATE successful !
   ```
   Reboot and check `/dev/mmcblk0p2` is to be used as the root filesystem while booting and the updated software version timestamp correctly:
   ```sh
   # dmesg | grep "root="
    [    0.000000] Kernel command line: console=ttyO0,115200n8 root=/dev/mmcblk0p2 rw rootfstype=ext4 rootwait
   # cat /etc/version
   20200302070450
   ```